#include "DisplayProxyMAX7456.h"

DisplayProxyMAX7456::DisplayProxyMAX7456(Max7456 *osd)
{
    this->osd = osd;
    this->osd->init(6);
    clear();
    this->osd->setBlinkParams(_8fields, _BT_3BT);

    externalVideo(false);
    onScreenDisplay(true);
}

/**
 * Write a text string to the display at the given position
 * @param x Position along the X axis
 * @param y Position along the Y axis
 * @param text The string to print
 * @return Success or false
 */
bool DisplayProxyMAX7456::write(int x, int y, const char *text)
{
    this->osd->print(text, x, y);
    return true;
}

/**
 * Clear the entire screen
 */
bool DisplayProxyMAX7456::clear()
{
    this->osd->clearScreen();
    return true;
}

/**
 * Adjust the display offset.
 * Since the signal is analog the characters might be rendered outside the display area
 */
bool DisplayProxyMAX7456::setOffset(int x, int y)
{
    this->osd->setDisplayOffsets(x, y);
    return true;
}

bool DisplayProxyMAX7456::externalVideo(bool enabled)
{
    this->osd->activateExternalVideo(enabled);
    return true;
}

bool DisplayProxyMAX7456::onScreenDisplay(bool enabled) 
{
    this->osd->activateOSD(enabled);
    return true;
}